@@ -14,7 +14,7 @@ use Scalar::Util qw(blessed);
 Readonly::Scalar our $EMPTY_STR => q{};
 
 # Version.
-our $VERSION = 0.02;
+our $VERSION = 0.03;
 
 # Constructor.
 sub new {
@@ -156,9 +156,25 @@ L<Scalar::Util>.
 
 =head1 SEE ALSO
 
-L<Lego::Part::Image::PeeronCom>,
-L<Lego::Part::Image::LegoCom>,
-L<Lego::Part::Image::LugnetCom>.
+=over
+
+=item L<Lego::Part::Image::PeeronCom>
+
+Lego part image class for peeron.com.
+
+=item L<Lego::Part::Image::LegoCom>
+
+Lego part image class for lego.com.
+
+=item L<Lego::Part::Image::LugnetCom>
+
+Lego part image class for lugnet.com.
+
+=item L<Task::Lego>
+
+Install the Lego modules.
+
+=back
 
 =head1 REPOSITORY
 
@@ -177,6 +193,6 @@ L<http://skim.cz>
 
 =head1 VERSION
 
-0.02
+0.03
 
 =cut
