@@ -9,7 +9,7 @@ use warnings;
 use Error::Pure qw(err);
 
 # Version.
-our $VERSION = 0.02;
+our $VERSION = 0.03;
 
 # Get image URL.
 sub image_url {
@@ -133,9 +133,25 @@ L<Lego::Part::Image>.
 
 =head1 SEE ALSO
 
-L<Lego::Part::Image>,
-L<Lego::Part::Image::LugnetCom>,
-L<Lego::Part::Image::PeeronCom>.
+=over
+
+=item L<Lego::Part::Image>
+
+Lego part image abstract class.
+
+=item L<Lego::Part::Image::PeeronCom>
+
+Lego part image class for peeron.com.
+
+=item L<Lego::Part::Image::LugnetCom>
+
+Lego part image class for lugnet.com.
+
+=item L<Task::Lego>
+
+Install the Lego modules.
+
+=back
 
 =head1 REPOSITORY
 
@@ -154,6 +170,6 @@ L<http://skim.cz>
 
 =head1 VERSION
 
-0.02
+0.03
 
 =cut
